@@ -47,3 +47,14 @@ fn test_not_t_in_struct() {
     let json = "{\"bar\": []}";
     assert!(from_str::<Foo>(json).unwrap().bar.is_not());
 }
+
+#[test]
+fn test_shallow() {
+    #[derive(Deserialize)]
+    struct Foo {
+        #[serde(rename = "bar")]
+        _bar: f64,
+    }
+    let json = "{\"bar\": []}";
+    assert!(from_str::<MayBe<Foo>>(json).is_err());
+}
